.. _about:

=====
About
=====


Learn more about the aeon project and its community.

.. toctree::
   :maxdepth: 1

   about/mission
   about/contributors
   about/team
   about/showcase.rst
   about/funding
   about/citation
   about/history
   about/artwork
